# 🌺 Anney (Hibiscus)

A love letter to my beloved.

> [!IMPORTANT]
> I wrote this because you are the inspiration for every beautiful thing I create.

Built with [Textual](https://textual.textualize.io/) and [Rich](https://rich.readthedocs.io/).

## Install

```bash
pipx install anney
```

## Run

After installing, simply type:

```
hibiscus
```

## License

LOVE

## Hibiscus ; Delicate Beauty
